@@ -97,7 +97,7 @@ KmagApp::KmagApp(QWidget* , const char* name)
   fpsArray.push_back(15); // high
   fpsArray.push_back(25); // very high
 
-  rotationArrayString << i18n("&No Rotation (0°)") << i18n("&Left (90°)") << i18n("&Upside Down (180°)") << i18n("&Right (270°)");
+  rotationArrayString << i18n("&No Rotation (0 Degrees)") << i18n("&Left (90 Degrees)") << i18n("&Upside Down (180 Degrees)") << i18n("&Right (270 Degrees)");
 
   rotationArray.push_back(0); // no rotation
   rotationArray.push_back(90); // left
@@ -634,7 +634,7 @@ void KmagApp::slotModeEdgeTop()
 {
   // ask for edgesize
   int newedgesize; bool ok;
-  newedgesize = KInputDialog::getInteger (i18n ("Magnifify to Screen Edge - Select Size"),
+  newedgesize = KInputDialog::getInteger (i18n ("Magnify to Screen Edge - Select Size"),
                                           i18n ("Size:"), edgesize > 0 ? edgesize : 300, 200,
                                           QApplication::desktop()->screenGeometry().height()/2,
                                           25, 10, &ok, 0, "getedgesize");
@@ -650,7 +650,7 @@ void KmagApp::slotModeEdgeLeft()
 {
   // ask for edgesize
   int newedgesize; bool ok;
-  newedgesize = KInputDialog::getInteger (i18n ("Magnifify to Left Screen Edge - Select Size"),
+  newedgesize = KInputDialog::getInteger (i18n ("Magnify to Left Screen Edge - Select Size"),
                                           i18n ("Size:"), edgesize > 0 ? edgesize : 300, 200,
                                           QApplication::desktop()->screenGeometry().width()/2,
                                           25, 10, &ok, 0, "getedgesize");
@@ -666,7 +666,7 @@ void KmagApp::slotModeEdgeRight()
 {
   // ask for edgesize
   int newedgesize; bool ok;
-  newedgesize = KInputDialog::getInteger (i18n ("Magnifify to Right Screen Edge - Select Size"),
+  newedgesize = KInputDialog::getInteger (i18n ("Magnify to Right Screen Edge - Select Size"),
                                           i18n ("Size:"), edgesize > 0 ? edgesize : 300, 200,
                                           QApplication::desktop()->screenGeometry().width()/2,
                                           25, 10, &ok, 0, "getedgesize");
@@ -682,7 +682,7 @@ void KmagApp::slotModeEdgeBottom()
 {
   // ask for edgesize
   int newedgesize; bool ok;
-  newedgesize = KInputDialog::getInteger (i18n ("Magnifify to Bottom Screen Edge - Select Size"),
+  newedgesize = KInputDialog::getInteger (i18n ("Magnify to Bottom Screen Edge - Select Size"),
                                           i18n ("Size:"), edgesize > 0 ? edgesize : 300, 200,
                                           QApplication::desktop()->screenGeometry().height()/2,
                                           25, 10, &ok, 0, "getedgesize");
